SystemOrganization addCategory: #MareaTests!
SystemOrganization addCategory: #'MareaTests-Serializers'!

!FuelCachedMareaSerializer methodsFor: '*MareaTests-Serializers' stamp: 'MarianoMartinezPeck 8/6/2011 23:23'!
internalMethodForTesting
	^ FLMaterializer methodDict at: #materialize! !

!AbstractMareaSerializer methodsFor: '*MareaTests-Serializers' stamp: 'MarianoMartinezPeck 8/6/2011 23:22'!
internalMethodForTesting
	^ self shouldBeImplemented ! !

TestCase subclass: #BaseGraphSwappingTest
	instanceVariableNames: 'proxyClass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MareaTests'!

!BaseGraphSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 23:35'!
installProxyOn: anObject. 
	^ self proxyClass installOn: anObject.! !

!BaseGraphSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 23:35'!
proxyClass
	^ proxyClass! !

!BaseGraphSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 23:35'!
serializer
	^ FuelMareaSerializer new! !

!BaseGraphSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 23:35'!
setUp
	ObjectProxySwapperHandler serializer: self serializer.
	proxyClass := NumberAsFilenameObjectProxySwapper.
	(FileDirectory default fileNamesMatching: '*.swap*') do: [ :aFile | FileDirectory default deleteFileNamed: aFile ].
	self proxyClass runningTest: true! !

!BaseGraphSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 23:35'!
tearDown
"	(FileDirectory default fileNamesMatching: '*.swap') 
		do: [ :aFile | FileDirectory default deleteFileNamed: aFile ]."! !

BaseGraphSwappingTest subclass: #GraphSwappingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MareaTests'!

!GraphSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 12:16'!
testAllRemovedByGC
	| anObject sharedObject anObjectHash size |
	
	3 timesRepeat: [Smalltalk garbageCollect].
	size := ClassWith2Var instanceCount.
	
	anObject := ClassWith2Var new.
	sharedObject := ClassWith1Var new. 
	sharedObject var1: 'nose'.
	anObject var1: Date today.
	anObject var2: sharedObject.
	anObjectHash := anObject identityHash.

	self assert: ClassWith2Var instanceCount equals: size + 1.
	
	self installProxyOn: anObject. 
	sharedObject := nil.
	3 timesRepeat: [Smalltalk garbageCollect].
	
	[self assert: ClassWith2Var instanceCount equals: size .
	
	"anObject and sharedObject should be garbageCollected"
	self assert: (anObject mareaSerializedObjects select: [:each | each class = ClassWith2Var]) isEmpty.
	self assert: (anObject mareaSerializedObjects select: [:each | each class = Date]) isEmpty.
	self assert: (anObject mareaSerializedObjects select: [:each | each class = ClassWith1Var]) isEmpty.
		
	anObject var2.
	self assert: ClassWith2Var instanceCount equals: size + 1.
	
	] ensure: [ anObject mareaIsProxy ifTrue:  [ anObject mareaUninstallIfNeeded]].

! !

!GraphSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 12:16'!
testInnerObjectsInGraph
	| anObject innerObject bkp|
	
	anObject := ClassWith1Var new.
	innerObject := Date today.
	bkp := innerObject asString. 
	anObject var1: innerObject.
	
	innerObject := nil.
	3 timesRepeat: [Smalltalk garbageCollect].
	
	self installProxyOn: anObject. 
	
	[self assert: anObject mareaClass equals: self proxyClass.
	self assert: anObject mareaIsProxyInstalled.
	anObject name.
	self assert: anObject class equals: ClassWith1Var.
	self assert: anObject var1 asString equals: bkp asString.

	] ensure: [ anObject mareaIsProxy ifTrue:  [ anObject mareaUninstallIfNeeded]].

! !

!GraphSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 12:16'!
testRootIsRemovedByGC
	| anObject sharedObject anObjectHash size |
	
	3 timesRepeat: [Smalltalk garbageCollect].
	size := ClassWith2Var instanceCount.
	
	anObject := ClassWith2Var new.
	sharedObject := ClassWith1Var new. 
	sharedObject var1: 'nose'.
	anObject var1: Date today.
	anObject var2: sharedObject.
	anObjectHash := anObject identityHash.

	self assert: ClassWith2Var instanceCount equals: size + 1.
	
	self installProxyOn: anObject. 
	3 timesRepeat: [Smalltalk garbageCollect].
	
	[self assert: ClassWith2Var instanceCount equals: size .
	
	"anObject should be garbageCollected but sharedObject no"
	self assert: (anObject mareaSerializedObjects select: [:each | each class = ClassWith2Var]) isEmpty.
	self assert: (anObject mareaSerializedObjects select: [:each | each class = Date]) isEmpty.
	self assert: ( anObject mareaSerializedObjects includes: sharedObject).
	self assert: ( anObject mareaSerializedObjects includes: 'nose').	
		
	anObject var2.
	self assert: ClassWith2Var instanceCount equals: size + 1.
	
	] ensure: [ anObject mareaIsProxy ifTrue:  [ anObject mareaUninstallIfNeeded]].

! !

!GraphSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 12:16'!
testSharedObjectsAreNotDuplicated
	| anObject sharedObject size |
	
	anObject := ClassWith2Var new.
	sharedObject := ClassWith1Var new. 
	sharedObject var1: 'nose'.
	anObject var1: Date today.
	anObject var2: sharedObject.
	
	self installProxyOn: anObject. 
	3 timesRepeat: [Smalltalk garbageCollect].
	
	[
	"anObject should be garbageCollected but sharedObject no"
	self assert: (anObject mareaSerializedObjects select: [:each | each class = ClassWith2Var]) isEmpty.
	self assert: (anObject mareaSerializedObjects select: [:each | each class = Date]) isEmpty.
	self assert: ( anObject mareaSerializedObjects includes: sharedObject).
	self assert: ( anObject mareaSerializedObjects includes: 'nose').	
		
	anObject var2.
	
	self assert: anObject var2 == sharedObject.
	
	] ensure: [ anObject mareaIsProxy ifTrue:  [ anObject mareaUninstallIfNeeded]].

! !

!GraphSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 12:16'!
testSharedObjectsInGraph
	| anObject sharedObject anObjectHash |
	
	anObject := ClassWith2Var new.
	sharedObject := ClassWith1Var new. 
	sharedObject var1: 'nose'.
	anObject var1: Date today.
	anObject var2: sharedObject.
	anObjectHash := anObject basicIdentityHash. 
	
	self installProxyOn: anObject. 
	3 timesRepeat: [Smalltalk garbageCollect].
	
	[self assert: anObject mareaClass equals: self proxyClass.
	self assert: anObject mareaIsProxyInstalled.
	anObject name.
	self assert: anObject class equals: ClassWith2Var.
	self assert: anObject var1 equals: Date today.
	self assert: anObject var2 == sharedObject.
	self assert: anObject var2 var1 = sharedObject var1.
	
	] ensure: [ anObject mareaIsProxy ifTrue:  [ anObject mareaUninstallIfNeeded]].

! !

BaseGraphSwappingTest subclass: #GraphWithProxiesSwappingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MareaTests'!

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 7/18/2011 13:55'!
testMaterializingAGraphThatHasAnAlreadyUninstalledProxy
	| anObject anArray |
	"This method demonstrates the problem when a proxy inside a graph is serialized and then, the original proxy is uninstalled before we materialize the graph."
	
	anObject := Date today.
	
	[
	self installProxyOn: anObject. 
	
	self assert: anObject mareaClass equals: self proxyClass.
	self assert: anObject mareaIsProxyInstalled.
	
	anArray := Array with: anObject.
	self installProxyOn: anArray.

	self assert: anArray first mareaClass equals: self proxyClass.
	self assert: anArray first mareaIsProxyInstalled.
	self deny: anArray mareaClass = self proxyClass.

	anObject day.
	"When uninstalling, there shouldn't be a problem even if the original proxy was uninstalled"
	self shouldnt:  [anArray first basicSize] raise: Error.

	self deny: anArray first mareaClass = self proxyClass.
	
	] ensure: [ 
	 anObject mareaIsProxy ifTrue:  [ anObject mareaUninstallIfNeeded].
	 anArray mareaIsProxy ifTrue:  [ anArray mareaUninstallIfNeeded].
	 anArray first mareaIsProxy ifTrue:  [ anArray first mareaUninstallIfNeeded].
	].

! !

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/5/2011 14:46'!
testProxyInsideGraphAndUninstalled
	"This test when there is a graph X and inside such graph, there is a proxy that represents a swapped subgraph Y. Y is materialized before X since it is a shared object it can be accessed."
	
	| a b c d |
	a := ClassWith2Var new.
	b := ClassWith2Var new. 
	c := ClassWith2Var new. 
	d := ClassWith1Var new. 
	
	a var1: b.
	a var2: c.
	c var1: 'c_var1'.
	c var2: d.
	b var1: 'b_var1'.
	b var2: 'b_var2'.
	d var1: 'd_var1'.
	
	self installProxyOn: b. 
	
	self assert: b mareaClass equals: self proxyClass.
	self assert: b mareaIsProxyInstalled.
	
	self installProxyOn: a.
	
	" 'b' has to continue be installed even if 'a' was serialized "
	self assert: b mareaClass equals: self proxyClass.
	self assert: b mareaIsProxyInstalled.
	 
	c := d := nil.
	
	b name.
	self deny: b mareaClass = self proxyClass.
	self deny: b mareaIsProxy.
	
	a name.
	
	self deny: a mareaClass = self proxyClass.
	self deny: a mareaIsProxy.
	
	self assert: b == a var1.
	

	! !

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/5/2011 15:40'!
testProxyInsideGraphButAddedLaterAndInstalled
	"This test when there is a graph X that is serialized and contains a shared object Y. Once serialized, a proxy is replaced by that shared object, generating a new proxy"
	
	| a b c d |
	a := ClassWith2Var new.
	b := ClassWith2Var new. 
	c := ClassWith2Var new. 
	d := ClassWith1Var new. 
	
	a var1: b.
	a var2: c.
	c var1: 'c_var1'.
	c var2: d.
	b var1: 'b_var1'.
	b var2: 'b_var2'.
	d var1: 'd_var1'.


	self installProxyOn: a.
	
	self installProxyOn: b. 
	
	self assert: a mareaClass equals: self proxyClass.
	self assert: a mareaIsProxyInstalled.

	self assert: b mareaClass equals: self proxyClass.
	self assert: b mareaIsProxyInstalled.

	 
	c := d := nil.
	
	b name.
	self deny: b mareaClass = self proxyClass.
	self deny: b mareaIsProxy.
	
	self assert: a mareaClass equals: self proxyClass.
	self assert: a mareaIsProxyInstalled.	
	
	a name.
	
	self deny: a mareaClass = self proxyClass.
	self deny: a mareaIsProxy.
		
	self assert: b == a var1.
	
	! !

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/5/2011 15:37'!
testProxyInsideGraphButAddedLaterAndNotInstalled
	"This test when there is a graph X that is serialized and contains a shared object Y. Once serialized, a proxy is replaced by that shared object, generating a new proxy"
	
	| a b c d |
	a := ClassWith2Var new.
	b := ClassWith2Var new. 
	c := ClassWith2Var new. 
	d := ClassWith1Var new. 
	
	a var1: b.
	a var2: c.
	c var1: 'c_var1'.
	c var2: d.
	b var1: 'b_var1'.
	b var2: 'b_var2'.
	d var1: 'd_var1'.


	self installProxyOn: a.
	
	self installProxyOn: b. 
	
	self assert: a mareaClass equals: self proxyClass.
	self assert: a mareaIsProxyInstalled.

	self assert: b mareaClass equals: self proxyClass.
	self assert: b mareaIsProxyInstalled.

	 
	c := d := nil.
	a name.
	
	self deny: a mareaClass = self proxyClass.
	self deny: a mareaIsProxy.
	
	" 'b' has to continue be installed even if 'a' was materialized "
	self assert: a var1 mareaClass equals: self proxyClass.
	self assert: a var1 mareaIsProxyInstalled.
	
	self assert: b mareaClass equals: self proxyClass.
	self assert: b mareaIsProxyInstalled.
	
	self assert: b == a var1.
	
	b name.
	self deny: b mareaClass = self proxyClass.
	self deny: b mareaIsProxy.! !

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/5/2011 14:42'!
testProxyInsideGraphButNotUninstalled
	"This test when there is a graph X and inside such graph, there is a proxy that represents a swapped subgraph Y. X is materialized before Y does it because since the proxy represents an inner object.  "
	
	| a b c d |
	a := ClassWith2Var new.
	b := ClassWith2Var new. 
	c := ClassWith2Var new. 
	d := ClassWith1Var new. 
	
	a var1: b.
	a var2: c.
	c var1: 'c_var1'.
	c var2: d.
	b var1: 'b_var1'.
	b var2: 'b_var2'.
	d var1: 'd_var1'.
	
	self installProxyOn: b. 
	
	self assert: b mareaClass equals: self proxyClass.
	self assert: b mareaIsProxyInstalled.
	
	self installProxyOn: a.
	
	" 'b' has to continue be installed even if 'a' was serialized "
	self assert: b mareaClass equals: self proxyClass.
	self assert: b mareaIsProxyInstalled.
	 
	c := d := nil.
	a name.
	
	self deny: a mareaClass = self proxyClass.
	self deny: a mareaIsProxy.
	
	" 'b' has to continue be installed even if 'a' was materialized "
	self assert: a var1 mareaClass equals: self proxyClass.
	self assert: a var1 mareaIsProxyInstalled.
	
	self assert: b mareaClass equals: self proxyClass.
	self assert: b mareaIsProxyInstalled.
	
	self assert: b == a var1.
	
	b name.
	self deny: b mareaClass = self proxyClass.
	self deny: b mareaIsProxy.
	
	! !

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 7/18/2011 12:05'!
testSerialiationOfProxy
	| aProxy materializedProxy |
	"This method tests that an instance of a proxy can be serialized and materialized WITHOUT being uninstalled, that is, without receiving a message that should be intercepted. "
	
	aProxy := self proxyClass newForTesting.
	aProxy mareaDefineFileNameFor: 'xxx'.
	self serializer serializeAndWriteObject: aProxy to: 'testSerialiationOfProxy.swap'.
	self shouldnt:  [materializedProxy := self serializer unserializeObjectFrom: 'testSerialiationOfProxy.swap'] raise: Error.
	self assert: aProxy mareaFileName equals: materializedProxy mareaFileName.
	! !

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 7/18/2011 10:56'!
testSerialiationOfProxyInsideAGraph
	| aProxy materializedObject anObject |
	"This method tests that an instance of a proxy can be serialized and materialized  inside a graph WITHOUT being uninstalled, that is, without receiving a message that should be intercepted. "
	
	aProxy := self proxyClass newForTesting.
	aProxy mareaDefineFileNameFor: 'xxx'.
	
	anObject := ClassWith2Var new.
	anObject var1: aProxy.
	anObject var2:  'mariano'.
	
	self serializer serializeAndWriteObject: anObject to: 'testSerialiationOfProxyInsideAGraph.swap'.
	self shouldnt:  [materializedObject := self serializer unserializeObjectFrom: 'testSerialiationOfProxyInsideAGraph.swap'] raise: Error.
	self assert: aProxy mareaFileName equals: materializedObject var1 mareaFileName.
	self assert: materializedObject var2 equals: 'mariano'.	! !

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 7/18/2011 11:03'!
testSerialiationOfProxyInsideAnArray
	| aProxy materializedObject anObject |
	"This method tests that an instance of a proxy can be serialized and materialized  inside an array  WITHOUT being uninstalled, that is, without receiving a message that should be intercepted. "
	
	aProxy := self proxyClass newForTesting.
	aProxy mareaDefineFileNameFor: 'xxx'.
	
	anObject := Array with: aProxy.
	
	self serializer serializeAndWriteObject: anObject to: 'testSerialiationOfProxyInsideAnArray.swap'.
	self shouldnt:  [materializedObject := self serializer unserializeObjectFrom: 'testSerialiationOfProxyInsideAnArray.swap'] raise: Error.
	self assert: aProxy mareaFileName equals: materializedObject first mareaFileName.
	! !

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 7/18/2011 11:30'!
testSwappingArrayWithProxy
	| anObject anArray |
	"This method demonstrates that when there is an array with a proxy instance, such proxy is ONLY uninstalled when sending messages to it. It is NOT uninstalled while serializing or materializing the graph that contains it. "
	
	anObject := Date today.
	
	[
	self installProxyOn: anObject. 
	
	self assert: anObject mareaClass equals: self proxyClass.
	self assert: anObject mareaIsProxyInstalled.
	
	anArray := Array with: anObject.
	self installProxyOn: anArray.

	self assert: anArray first mareaClass equals: self proxyClass.
	self assert: anArray first mareaIsProxyInstalled.
	self deny: anArray mareaClass = self proxyClass.

	anArray first basicSize.

	self deny: anArray first mareaClass = self proxyClass.
	
	] ensure: [ 
	 anArray mareaIsProxy ifTrue:  [ anArray mareaUninstallIfNeeded].
	 anArray first mareaIsProxy ifTrue:  [ anArray first mareaUninstallIfNeeded].
	].

! !

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 7/18/2011 11:31'!
testSwappingGraphWithProxy
	| anObject anArray |
	"This method demonstrates that when there is an graph with a proxy instance, such proxy is ONLY uninstalled when sending messages to it. It is NOT uninstalled while serializing or materializing the graph that contains it. "
	
	anObject := Date today.
	
	[
	self installProxyOn: anObject. 
	
	self assert: anObject mareaClass equals: self proxyClass.
	self assert: anObject mareaIsProxyInstalled.
	
	anArray := ClassWith1Var new var1: anObject.
	self installProxyOn: anArray.

	self assert: anArray var1 mareaClass equals: self proxyClass.
	self assert: anArray var1 mareaIsProxyInstalled.
	self deny: anArray mareaClass = self proxyClass.

	anArray var1 basicSize.

	self deny: anArray var1 mareaClass = self proxyClass.
	
	] ensure: [ 
	 anArray mareaIsProxy ifTrue:  [ anArray mareaUninstallIfNeeded].
	 anArray var1 mareaIsProxy ifTrue:  [ anArray first mareaUninstallIfNeeded].
	].

! !

!GraphWithProxiesSwappingTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 7/18/2011 13:58'!
testUninstallingOriginalProxyWhichWasMaterializedAndUninstalled
	| anObject anArray |
	"This method demonstrates the problem in the scenario when 
	- a proxy inside a graph is serialized. 
	- the graph is materialized and the original proxy is uninstalled
	- finally the original proxy tries to uninstall"
	
	anObject := Date today.
	
	[
	self installProxyOn: anObject. 
	
	self assert: anObject mareaClass equals: self proxyClass.
	self assert: anObject mareaIsProxyInstalled.
	
	anArray := Array with: anObject.
	self installProxyOn: anArray.

	self assert: anArray first mareaClass equals: self proxyClass.
	self assert: anArray first mareaIsProxyInstalled.
	self deny: anArray mareaClass = self proxyClass.

	anArray first basicSize.	
	"When uninstalling, there shouldn't be a problem even if the materialized proxy was uninstalled"
	self shouldnt:  [anObject day.] raise: Error.

	self deny: anArray first mareaClass = self proxyClass.
	
	] ensure: [ 
	 anObject mareaIsProxy ifTrue:  [ anObject mareaUninstallIfNeeded].
	 anArray mareaIsProxy ifTrue:  [ anArray mareaUninstallIfNeeded].
	 anArray first mareaIsProxy ifTrue:  [ anArray first mareaUninstallIfNeeded].
	].

! !

TestCase subclass: #FuelSerializerTest
	instanceVariableNames: 'proxyClass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MareaTests-Serializers'!

!FuelSerializerTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/2/2011 14:14'!
installProxyOn: anObject. 
	^ self proxyClass installOn: anObject.! !

!FuelSerializerTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/2/2011 14:14'!
proxyClass
	^ proxyClass! !

!FuelSerializerTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/2/2011 14:14'!
setUp
	ObjectProxySwapperHandler serializer: FuelMareaSerializer new. 
	proxyClass := NumberAsFilenameObjectProxySwapper.
	(FileDirectory default fileNamesMatching: '*.swap*') 
		do: [ :aFile | FileDirectory default deleteFileNamed: aFile ].
	self proxyClass runningTest: true.
	! !

!FuelSerializerTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/3/2011 15:54'!
tearDown
	(FileDirectory default fileNamesMatching: '*.fuel') 
		do: [ :aFile | FileDirectory default deleteFileNamed: aFile ]! !

!FuelSerializerTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/3/2011 18:44'!
testSerializedObjectsIsWeak
	| anObject anotherObject serializedObjects size |

	3 timesRepeat: [Smalltalk garbageCollect]. 
	size := ClassWith1Var allInstances size.
	
	anObject := ClassWith2Var new.
	anotherObject := ClassWith1Var new. 
	anotherObject var1: 'nose'.
	anObject var1: 'mariano'.
	anObject var2: anotherObject.

	serializedObjects := FuelMareaSerializer new serializeAndWriteObject: anObject to: 'testSerializedObjectsIsWeak.fuel'.

	anotherObject := nil.
	anObject var2: nil.
	3 timesRepeat: [Smalltalk garbageCollect]. 
	self assert: (ClassWith1Var allInstances size - size) equals: 0.
	
	self assert: (serializedObjects includes: nil).	
! !

!FuelSerializerTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 8/6/2011 11:51'!
testSerializedObjectsMaterialization
	| anObject anotherObject serializedObjects size anObjectMaterialized |

	3 timesRepeat: [Smalltalk garbageCollect]. 
	size := ClassWith1Var allInstances size.
	
	anObject := ClassWith2Var new.
	anotherObject := ClassWith1Var new. 
	anotherObject var1: 'nose'.
	anObject var1: 'mariano'.
	anObject var2: anotherObject.

	serializedObjects := FuelMareaSerializer new serializeAndWriteObject: anObject to: 'testSerializedObjectsMaterialization2.fuel'.

	anObject := nil.
	3 timesRepeat: [Smalltalk garbageCollect]. 
	
	anObjectMaterialized := FuelMareaSerializer new unserializeObjectFrom: 'testSerializedObjectsMaterialization2.fuel' serializedObjects:  serializedObjects rootProxy: nil.

	self assert: anObjectMaterialized var1 equals: 'mariano'.
	self assert: anotherObject == anObjectMaterialized var2.
	self assert: anotherObject var1 == anObjectMaterialized var2 var1.  
	
	! !

!FuelMareaSerializer methodsFor: '*MareaTests-Serializers' stamp: 'MarianoMartinezPeck 8/6/2011 23:23'!
internalMethodForTesting
	^ FLMaterializer methodDict at: #materialize! !
